%define anolis_release 1
%global commit0 faa23f21fc677af5792825dc30cb1ccef4bf33a6

Summary:        The GL Vendor-Neutral Dispatch library
Name:           libglvnd
Version:        1.7.0
Release:        %{anolis_release}%{?dist}
Epoch:          1

License:        MIT
URL:            https://gitlab.freedesktop.org/glvnd/libglvnd
Source0:        %{url}/-/archive/v%{version}/%{name}-%{version}.tar.gz
Patch001:	0001-add-loongarch64-support-for-libglvnd.patch

# CVE-2023-45924
# Upstream fix: https://gitlab.freedesktop.org/glvnd/libglvnd/-/merge_requests/295/diffs?commit_id=16f5f0e2a520d730cbc33f76ba4d7b94a200f740
Patch002: Bugfix-for-CVE-2023-45924.patch

BuildRequires:  meson >= 0.48.0 gcc > 12.0 libtool
BuildRequires:  python3-rpm-macros python3-libxml2
BuildRequires:  pkgconfig(glproto) pkgconfig(x11) pkgconfig(xext)
BuildRequires:  xorg-x11-server-Xvfb


%description
libglvnd is a vendor-neutral dispatch layer for arbitrating OpenGL API calls
between multiple vendors. It allows multiple drivers from different vendors
to coexist on the same filesystem, and determines which vendor to dispatch
each API call to at runtime. Both GLX and EGL are supported, in any combination
with OpenGL and OpenGL ES.


%package        opengl
Summary:        OpenGL support for libglvnd
Requires:       %{name} = %{epoch}:%{version}-%{release}

%description    opengl
libOpenGL is the common dispatch interface for the workstation OpenGL API.


%package        gles
Summary:        GLES support for libglvnd
Requires:       %{name} = %{epoch}:%{version}-%{release}
Requires:       mesa-libEGL >= 13.0.4
Obsoletes:      mesa-libGLES < 19.3.0
Provides:       mesa-libGLES
Provides:       libGLES

%description    gles
libGLESv are the common dispatch interface for the GLES API.


%package        egl
Summary:        EGL support for libglvnd
Requires:       %{name} = %{epoch}:%{version}-%{release}
Requires:       mesa-libEGL >= 13.0.4
Provides:       libEGL

%description    egl
libEGL are the common dispatch interface for the EGL API.


%package        glx
Summary:        GLX support for libglvnd
Requires:       %{name} = %{epoch}:%{version}-%{release}
Requires:       mesa-libGL >= 13.0.4
Provides:       libGL

%description    glx
libGL and libGLX are the common dispatch interface for the GLX API.



%package        core-devel
Summary:        Core development files for %{name}

%description core-devel
The %{name}-core-devel package is a bootstrap trick for Mesa, which wants
to build against the %{name} headers but does not link against any of
its libraries (and, initially, has file conflicts with them). If you are
not Mesa you almost certainly want %{name}-devel instead.


%package        devel
Summary:        Development files for %{name}
Requires:       %{name} = %{epoch}:%{version}-%{release}
Requires:       %{name}-opengl = %{epoch}:%{version}-%{release}
Requires:       %{name}-glx = %{epoch}:%{version}-%{release}
Requires:       %{name}-gles = %{epoch}:%{version}-%{release}
Requires:       %{name}-egl = %{epoch}:%{version}-%{release}
Requires:       %{name}-core-devel = %{epoch}:%{version}-%{release}
Requires:       libX11-devel
Obsoletes:      mesa-libGLES-devel < 19.3.0
Obsoletes:      mesa-khr-devel < 19.3.0
Provides:       mesa-libGLES-devel = %{epoch}:%{version}-%{release}
Provides:       mesa-khr-devel = %{epoch}:%{version}-%{release}
Provides:       libGLES-devel = %{epoch}:%{version}-%{release}

%description    devel
The %{name}-devel package provides headers and development libraries
needed to develop programs that use %{name}.

%package doc
Summary:        Documentation files for %{name}
Requires:       %{name} = %{epoch}:%{version}-%{release}
BuildArch:      noarch

%description    doc
The %{name}-doc package contains documentation files for %{name}.


%prep
%autosetup -p1 -n %{name}-v%{version}-%{?commit0}

%build
%meson -Dasm=enabled -Dtls=true
%meson_build

%install
%meson_install

mkdir -p %{buildroot}%{_sysconfdir}/glvnd/egl_vendor.d/
mkdir -p %{buildroot}%{_datadir}/glvnd/egl_vendor.d/
mkdir -p %{buildroot}%{_sysconfdir}/egl/egl_external_platform.d/
mkdir -p %{buildroot}%{_datadir}/egl/egl_external_platform.d/

%generate_compatibility_deps

%check
%ifarch x86_64
xvfb-run -s '-screen 0 640x480x24' -d \
  %{__meson} test \
  -C %{_vpath_builddir} \
  --num-processes %{_smp_build_ncpus}
%endif

%files
%dir %{abidir}
%dir %{_sysconfdir}/glvnd/
%dir %{_datadir}/glvnd/
%{_libdir}/libGLdispatch.so.0*
%{abidir}/libGLdispatch.dump

%files opengl
%{_libdir}/libOpenGL.so.0*
%{abidir}/libOpenGL.dump

%files gles
%{_libdir}/libGLES*.so.*
%{abidir}/libGLES*.dump

%files glx
%{_libdir}/libGL.so.*
%{_libdir}/libGLX.so.*
%{abidir}/libGL.dump
%{abidir}/libGLX.dump

%files egl
%dir %{_sysconfdir}/glvnd/egl_vendor.d/
%dir %{_datadir}/glvnd/egl_vendor.d/
%dir %{_sysconfdir}/egl/
%dir %{_sysconfdir}/egl/egl_external_platform.d/
%dir %{_datadir}/egl/
%dir %{_datadir}/egl/egl_external_platform.d/
%{_libdir}/libEGL*.so.*
%{abidir}/libEGL*.dump

%files core-devel
%dir %{_includedir}/glvnd/
%{_includedir}/glvnd/*.h
%{_libdir}/pkgconfig/libglvnd.pc

%files devel
%dir %{_includedir}/EGL/
%dir %{_includedir}/GL/
%dir %{_includedir}/GLES/
%dir %{_includedir}/GLES2/
%dir %{_includedir}/GLES3/
%dir %{_includedir}/KHR/
%{_includedir}/EGL/*.h
%{_includedir}/GL/*.h
%{_includedir}/GLES/*.h
%{_includedir}/GLES2/*.h
%{_includedir}/GLES3/*.h
%{_includedir}/KHR/*.h
%{_libdir}/lib*.so
%{_libdir}/pkgconfig/gl*.pc
%{_libdir}/pkgconfig/egl.pc
%{_libdir}/pkgconfig/opengl.pc

%files doc
%doc README.md


%changelog
* Wed Mar 19 2025 mgb01105731 <mgb01105731@alibaba-inc.com> - 1:1.7.0-1
- Update to 1.7.0 from 1.6.0

* Wed Aug 07 2024 lidongyue <dongyue@nfschina.com> - 1:1.6.0-4
- Fix CVE-2023-45924

* Fri Aug  4 2023 Wenlong Zhang<zhangwenlong@loongson.cn> - -1:1.6.0-3
- add loongarch64 support for libglvnd

* Tue Apr 11 2023 Ziyang Zhang <ZiyangZhang@linux.alibaba.com> -1:1.6.0-2
- Optimize spec file

* Sun Jan 8 2023 Funda Wang <fundawang@yeah.net> - 1:1.6.0-1
- New version 1.6.0
- Use meson for faster build

* Tue Oct 25 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 1:1.5.0-2
- optimise spec file

* Mon Sep 19 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 1:1.5.0-1
- update to 1.5.0

* Thu Apr 21 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 1:1.4.0-1
- Init from upstream version 1.4.0

